==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/eu.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Berreskurapen gakoaren pasahitza falta da",
    "Please repeat the recovery key password" : "Mesedez errepikatu berreskuratze gakoaren pasahitza",
    "Repeated recovery key password does not match the provided recovery key password" : "Errepikatutako berreskuratze gakoaren pasahitza ez dator bat berreskuratze gakoaren pasahitzarekin",
    "Recovery key successfully enabled" : "Berreskuratze gakoa behar bezala gaitua",
    "Could not enable recovery key. Please check your recovery key password!" : "Ezin da berreskuratze gako gaitu. Egiaztatu berreskuratze gako pasahitza!",
    "Recovery key successfully disabled" : "Berreskuratze gakoa behar bezala desgaitu da",
    "Could not disable recovery key. Please check your recovery key password!" : "Ezin da berreskuratze gako desgaitu. Egiaztatu berreskuratze gako pasahitza!",
    "Missing parameters" : "Parametroak faltan",
    "Please provide the old recovery password" : "Mesedez sartu berreskuratze pasahitz zaharra",
    "Please provide a new recovery password" : "Mesedez sartu berreskuratze pasahitz berria",
    "Please repeat the new recovery password" : "Mesedez errepikatu berreskuratze pasahitz berria",
    "Password successfully changed." : "Pasahitza behar bezala aldatu da.",
    "Could not change the password. Maybe the old password was not correct." : "Ezin izan da pasahitza aldatu. Agian pasahitz zaharra okerrekoa da.",
    "Recovery Key disabled" : "Berreskuratze gakoa desgaituta",
    "Recovery Key enabled" : "Berreskuratze gakoa gaituta",
    "Could not enable the recovery key, please try again or contact your administrator" : "Ezin da berreskuratze gakoa gaitu, saia zaitez berriz mesedez edo zureadministratzailearekin kontaktuan jarri",
    "Could not update the private key password." : "Ezin izan da gako pribatu pasahitza eguneratu. ",
    "The old password was not correct, please try again." : "Pasahitz zaharra ez da egokia. Mesedez, saiatu berriro.",
    "The current log-in password was not correct, please try again." : "Oraingo pasahitza ez da egokia. Mesedez, saiatu berriro.",
    "Private key password successfully updated." : "Gako pasahitz pribatu behar bezala eguneratu da.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Zure enkriptatze gakoak enkriptatze zaharretik (ownCloud <=8.0) berrira migratubehar duzu. 'occ encryption:migrate' exekuta ezazu mesedez, edo zure administratzailearekin kontaktuan jar zaitez",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Enkriptazio aplikaziorako gako pribatu desegokia. Zure gako pribatuaren pasahitza eguneratuezarpen pertsonaletan, enkriptatutako fitxategiak berriz atzitu nahi badituzu",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Enkriptazioa app-a gaituta dago, baina zure gakoak ez dira hasieratu. Saiotikirten eta berriz sartu, mesedez",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Enkriptazio modulua erabili ahal izateko zerbitzariaren aldean enkriptazioagaitu administrazio ezarpenetan",
    "Encryption app is enabled and ready" : "Enkriptazioa app-a gaituta eta martxan dago",
    "Bad Signature" : "Sinadura ezegokia",
    "Missing Signature" : "Sinadura falta da",
    "one-time password for server-side-encryption" : "aldi bateko pasahitzak zerbitzari-aldeko enkriptaziorako",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ezin izan da fitxategi hau deszifratu, ziurrenik elkarbanatutako fitxategi bat da. Mesdez, eskatu fitxategiaren jabeari fitxategia zurekin berriz elkarbana dezan.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ezin da fitxategi hau irakurri, ziur aski partekatutako fitxategia izango da. Fitxategiaren jabeari berriz partekatzeko eska iezaiozu",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Kaixo\n\nadministradoreak zerbitzari-aldeko enkriptazioa gaitu du. Zure fitxategiak '%s' pasahitza erabiliz enkriptatuko dira.\n\nWeb interfazea saioa hasi, 'oinarrizko enkripazio modulua' atalera joan zaitez eta pasahitza eguneratu.  Hortarako pasahitz zaharra 'pasahitz zaharra' atalean sartu eta zure oraingo pasahitza",
    "The share will expire on %s." : "Elkarbanaketa %s-n iraungiko da.",
    "Cheers!" : "Ongi izan!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Kaixo<br><br>administradoreak zerbitzari-aldeko enkriptazioa gaitu du. Zure fitxategiak '%s' pasahitza erabiliz enkriptatuko dira.\n\nWeb interfazea saioa hasi, 'oinarrizko enkripazio modulua' atalera joan zaitez eta pasahitza eguneratu.  Hortarako pasahitz zaharra 'pasahitz zaharra' atalean sartu eta zure oraingo pasahitza",
    "Default encryption module" : "Defektuzko enkriptazio modulua",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Enkriptazio app-a gaituta dago baina zure gakoak ez dira hasieratu, mesedez saiotik irteneta berriz sar zaitez",
    "Encrypt the home storage" : "Etxe-biltegia enkriptatu",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Aukera hau gaituz gero biltegi orokorreko fitxategi guztiak enkriptatuko dirabestela kanpo biltegian daudenak bakarrik enkriptatuko dira",
    "Enable recovery key" : "Berreskuratze gakoa gaitu",
    "Disable recovery key" : "Berreskuratze gakoa desgaitu",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Berreskuratze gakoa fitxategiak enkriptatzeko gako extra bat da.Erabiltzailearen fitxategiak berreskuratzea baimentzen du bere pasahitzagalduz gero.",
    "Recovery key password" : "Berreskuratze gako pasahitza",
    "Repeat recovery key password" : "Berreskuratze gakoaren pasahitza errepikatu",
    "Change recovery key password:" : "Aldatu berreskuratze gako pasahitza:",
    "Old recovery key password" : "Berreskuratze gako zaharraren pasahitza",
    "New recovery key password" : "Berreskuratze gako berriaren pasahitza",
    "Repeat new recovery key password" : "Berreskuratze gakoaren pasahitz berria errepikatu",
    "Change Password" : "Aldatu Pasahitza",
    "Basic encryption module" : "Oinarrizko enkriptazio modulua",
    "Your private key password no longer matches your log-in password." : "Zure gako pasahitza pribatua ez da dagoeneko bat etortzen zure sartzeko pasahitzarekin.",
    "Set your old private key password to your current log-in password:" : "Ezarri zure gako pasahitz zaharra orain duzun  sartzeko pasahitzan:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Ez baduzu zure pasahitz zaharra gogoratzen eskatu zure administratzaileari zure fitxategiak berreskuratzeko.",
    "Old log-in password" : "Sartzeko pasahitz zaharra",
    "Current log-in password" : "Sartzeko oraingo pasahitza",
    "Update Private Key Password" : "Eguneratu gako pasahitza pribatua",
    "Enable password recovery:" : "Gaitu pasahitzaren berreskuratzea:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aukera hau gaituz zure enkriptatutako fitxategiak berreskuratu ahal izango dituzu pasahitza galtzekotan",
    "Enabled" : "Gaitua",
    "Disabled" : "Ez-gaitua"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/eu.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Berreskurapen gakoaren pasahitza falta da",
    "Please repeat the recovery key password" : "Mesedez errepikatu berreskuratze gakoaren pasahitza",
    "Repeated recovery key password does not match the provided recovery key password" : "Errepikatutako berreskuratze gakoaren pasahitza ez dator bat berreskuratze gakoaren pasahitzarekin",
    "Recovery key successfully enabled" : "Berreskuratze gakoa behar bezala gaitua",
    "Could not enable recovery key. Please check your recovery key password!" : "Ezin da berreskuratze gako gaitu. Egiaztatu berreskuratze gako pasahitza!",
    "Recovery key successfully disabled" : "Berreskuratze gakoa behar bezala desgaitu da",
    "Could not disable recovery key. Please check your recovery key password!" : "Ezin da berreskuratze gako desgaitu. Egiaztatu berreskuratze gako pasahitza!",
    "Missing parameters" : "Parametroak faltan",
    "Please provide the old recovery password" : "Mesedez sartu berreskuratze pasahitz zaharra",
    "Please provide a new recovery password" : "Mesedez sartu berreskuratze pasahitz berria",
    "Please repeat the new recovery password" : "Mesedez errepikatu berreskuratze pasahitz berria",
    "Password successfully changed." : "Pasahitza behar bezala aldatu da.",
    "Could not change the password. Maybe the old password was not correct." : "Ezin izan da pasahitza aldatu. Agian pasahitz zaharra okerrekoa da.",
    "Recovery Key disabled" : "Berreskuratze gakoa desgaituta",
    "Recovery Key enabled" : "Berreskuratze gakoa gaituta",
    "Could not enable the recovery key, please try again or contact your administrator" : "Ezin da berreskuratze gakoa gaitu, saia zaitez berriz mesedez edo zureadministratzailearekin kontaktuan jarri",
    "Could not update the private key password." : "Ezin izan da gako pribatu pasahitza eguneratu. ",
    "The old password was not correct, please try again." : "Pasahitz zaharra ez da egokia. Mesedez, saiatu berriro.",
    "The current log-in password was not correct, please try again." : "Oraingo pasahitza ez da egokia. Mesedez, saiatu berriro.",
    "Private key password successfully updated." : "Gako pasahitz pribatu behar bezala eguneratu da.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Enkriptazio aplikaziorako gako pribatu desegokia. Zure gako pribatuaren pasahitza eguneratuezarpen pertsonaletan, enkriptatutako fitxategiak berriz atzitu nahi badituzu",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Enkriptazioa app-a gaituta dago, baina zure gakoak ez dira hasieratu. Saiotikirten eta berriz sartu, mesedez",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Enkriptazio modulua erabili ahal izateko zerbitzariaren aldean enkriptazioagaitu administrazio ezarpenetan",
    "Encryption app is enabled and ready" : "Enkriptazioa app-a gaituta eta martxan dago",
    "Bad Signature" : "Sinadura ezegokia",
    "Missing Signature" : "Sinadura falta da",
    "one-time password for server-side-encryption" : "aldi bateko pasahitzak zerbitzari-aldeko enkriptaziorako",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ezin izan da fitxategi hau deszifratu, ziurrenik elkarbanatutako fitxategi bat da. Mesdez, eskatu fitxategiaren jabeari fitxategia zurekin berriz elkarbana dezan.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ezin da fitxategi hau irakurri, ziur aski partekatutako fitxategia izango da. Fitxategiaren jabeari berriz partekatzeko eska iezaiozu",
    "Default encryption module" : "Defektuzko enkriptazio modulua",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Kaixo\n\nadministradoreak zerbitzari-aldeko enkriptazioa gaitu du. Zure fitxategiak '%s' pasahitza erabiliz enkriptatuko dira.\n\nWeb interfazea saioa hasi, 'oinarrizko enkripazio modulua' atalera joan zaitez eta pasahitza eguneratu.  Hortarako pasahitz zaharra 'pasahitz zaharra' atalean sartu eta zure oraingo pasahitza",
    "The share will expire on %s." : "Elkarbanaketa %s-n iraungiko da.",
    "Cheers!" : "Ongi izan!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Kaixo<br><br>administradoreak zerbitzari-aldeko enkriptazioa gaitu du. Zure fitxategiak '%s' pasahitza erabiliz enkriptatuko dira.\n\nWeb interfazea saioa hasi, 'oinarrizko enkripazio modulua' atalera joan zaitez eta pasahitza eguneratu.  Hortarako pasahitz zaharra 'pasahitz zaharra' atalean sartu eta zure oraingo pasahitza",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Enkriptazio app-a gaituta dago baina zure gakoak ez dira hasieratu, mesedez saiotik irteneta berriz sar zaitez",
    "Encrypt the home storage" : "Etxe-biltegia enkriptatu",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Aukera hau gaituz gero biltegi orokorreko fitxategi guztiak enkriptatuko dirabestela kanpo biltegian daudenak bakarrik enkriptatuko dira",
    "Enable recovery key" : "Berreskuratze gakoa gaitu",
    "Disable recovery key" : "Berreskuratze gakoa desgaitu",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Berreskuratze gakoa fitxategiak enkriptatzeko gako extra bat da.Erabiltzailearen fitxategiak berreskuratzea baimentzen du bere pasahitzagalduz gero.",
    "Recovery key password" : "Berreskuratze gako pasahitza",
    "Repeat recovery key password" : "Berreskuratze gakoaren pasahitza errepikatu",
    "Change recovery key password:" : "Aldatu berreskuratze gako pasahitza:",
    "Old recovery key password" : "Berreskuratze gako zaharraren pasahitza",
    "New recovery key password" : "Berreskuratze gako berriaren pasahitza",
    "Repeat new recovery key password" : "Berreskuratze gakoaren pasahitz berria errepikatu",
    "Change Password" : "Aldatu Pasahitza",
    "Basic encryption module" : "Oinarrizko enkriptazio modulua",
    "Your private key password no longer matches your log-in password." : "Zure gako pasahitza pribatua ez da dagoeneko bat etortzen zure sartzeko pasahitzarekin.",
    "Set your old private key password to your current log-in password:" : "Ezarri zure gako pasahitz zaharra orain duzun  sartzeko pasahitzan:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Ez baduzu zure pasahitz zaharra gogoratzen eskatu zure administratzaileari zure fitxategiak berreskuratzeko.",
    "Old log-in password" : "Sartzeko pasahitz zaharra",
    "Current log-in password" : "Sartzeko oraingo pasahitza",
    "Update Private Key Password" : "Eguneratu gako pasahitza pribatua",
    "Enable password recovery:" : "Gaitu pasahitzaren berreskuratzea:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aukera hau gaituz zure enkriptatutako fitxategiak berreskuratu ahal izango dituzu pasahitza galtzekotan",
    "Enabled" : "Gaitua",
    "Disabled" : "Ez-gaitua",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Zure enkriptatze gakoak enkriptatze zaharretik (ownCloud <=8.0) berrira migratubehar duzu. 'occ encryption:migrate' exekuta ezazu mesedez, edo zure administratzailearekin kontaktuan jar zaitez"
},
"nplurals=2; plural=(n != 1);");
